﻿using System.Collections.Generic;
using Ato.EN.IntegrationServices.CodeGenerationCGTS;
using Ato.EN.IntegrationServices.CodeGenerationDDCTNS;
using Ato.EN.IntegrationServices.CodeGenerationINCDTLS;
using Ato.EN.IntegrationServices.CodeGenerationNRFI;
using Ato.EN.IntegrationServices.CodeGenerationRNTLPRPTY;

namespace Ato.EN.IntegrationServices.CodeGenerationIITR
{
    public class IITR2022Crossform
    {
        #region Entities

        // Create Variables to store the Consumed Entity objects. 
        // These are required to be lists so that we can validate the cardinality in the event that more than one schedule is submitted.

        // IITR Parent Document
        public IITR2022 iitrParentDocument = null;

        // CGTS Child Documents
        public List<CGTS2018> cgtsChildDocuments = null;

        // DDCTNS Child Documents
        public List<DDCTNS2019> ddctnsChildDocuments = null;

        // INCDTLS Child Documents
        public List<INCDTLS2022> incdtlsChildDocuments = null;

        // NRFI Child Documents
        public List<NRFI2018> nrfiChildDocuments = null;

        // RNTLPRPTY Child Documents
        public List<RNTLPRPTY2019> rntlprptyChildDocuments = null;

        #endregion Entities

        #region Entity Accessor Properties

        // Simplifies the code that uses the crossform Entity so that it does not have to access an array.

        // IITR
        public IITR2022 IITR
        {
            get { return iitrParentDocument; }
        }

        // CGTS
        public CGTS2018 CGTS
        {
            get { return cgtsChildDocuments?[0]; }
        }

        // DDCTNS
        public DDCTNS2019 DDCTNS
        {
            get { return ddctnsChildDocuments?[0]; }
        }

        // INCDTLS
        public INCDTLS2022 INCDTLS
        {
            get { return incdtlsChildDocuments?[0]; }
        }

        // NRFI
        public NRFI2018 NRFI
        {
            get { return nrfiChildDocuments?[0]; }
        }

        // RNTLPRPTY
        public RNTLPRPTY2019 RNTLPRPTY
        {
            get { return rntlprptyChildDocuments?[0]; }
        }

        #endregion Entity Accessor Properties

        #region Constructors

        public IITR2022Crossform()
        {
            // Blank constructor to support construction of object when there is an unknown number of reports.
        }

        /// <summary>
        /// Setup the Child documents with their respective entity objects.
        /// </summary>
        /// <param name="iitr2022">Consumed IITR2022 entity object - This should always be provided.</param>
        /// <param name="ddctns2019">Consumed DDCTNS2019 entity object</param>
        /// <param name="INCDTLS2022">Consumed INCDTLS2022 entity object</param>
        /// <param name="rntlprpty2019">Consumed RNTLPRPTY2019 entity object</param>
        /// <param name="cgts2018">Consumed CGTS2018 entity object</param>
        /// <param name="nrfi2018">Consumed NRFI entity object</param>
        public IITR2022Crossform(IITR2022 iitr2022, DDCTNS2019 ddctns2019 = null, INCDTLS2022 incdtls2022 = null, RNTLPRPTY2019 rntlprpty2019 = null, CGTS2018 cgts2018 = null, NRFI2018 nrfi2018 = null)
        {
            // Set the IITR Parent Document (This will always be provided)
            iitrParentDocument = iitr2022;

            if (ddctns2019 != null)
            {
                ddctnsChildDocuments = new List<DDCTNS2019>()
                {
                    ddctns2019
                };
            }

            if (incdtls2022 != null)
            {
                incdtlsChildDocuments = new List<INCDTLS2022>()
                {
                    incdtls2022
                };
            }

            if (rntlprpty2019 != null)
            {
                rntlprptyChildDocuments = new List<RNTLPRPTY2019>()
                {
                    rntlprpty2019
                };
            }

            if (cgts2018 != null)
            {
                cgtsChildDocuments = new List<CGTS2018>()
                {
                    cgts2018
                };
            }

            if (nrfi2018 != null)
            {
                nrfiChildDocuments = new List<NRFI2018>()
                {
                    nrfi2018
                };
            }
        }

        #endregion Constructors

    }
}